@@ -156,7 +156,7 @@ absorptance_spct <-
     }
     temp.spct <- setGenericSpct(temp.spct)
     # if the waveband is undefined then use all data
-    if (is.null(w.band)) {
+    if (length(w.band) == 0) {
       w.band <- waveband(spct)
     }
     if (is.numeric(w.band)) {
